$.jqplot.LinearAxisRenderer

The default jqPlot axis renderer, creating a numeric axis.

Summary

$.jqplot.LinearAxisRenderer | The default jqPlot axis renderer, creating a numeric axis.
Properties |
breakPoints | EXPERIMENTAL!!
breakTickLabel | Label to use at the axis break if breakPoints are specified.
drawBaseline | True to draw the axis baseline.
baselineWidth | width of the baseline in pixels.
baselineColor | CSS color spec for the baseline.
forceTickAt0 | This will ensure that there is always a tick mark at 0.
forceTickAt100 | This will ensure that there is always a tick mark at 100.
tickInset | Controls the amount to inset the first and last ticks from the edges of the grid, in multiples of the tick interval.
minorTicks | Number of ticks to add between “major” ticks.
alignTicks | true to align tick marks across opposed axes such as from the y2axis to yaxis.

### Properties

### breakPoints

> this.breakPoints = null

EXPERIMENTAL!! Use at your own risk! Works only with linear axes and the default tick renderer. Array of [start, stop] points to create a broken axis. Broken axes have a “jump” in them, which is an immediate transition from a smaller value to a larger value. Currently, axis ticks MUST be manually assigned if using breakPoints by using the axis ticks array option.

### breakTickLabel

> this.breakTickLabel = "&asymp

Label to use at the axis break if breakPoints are specified.

### drawBaseline

> this.drawBaseline = true

True to draw the axis baseline.

### baselineWidth

> this.baselineWidth = null

width of the baseline in pixels.

### baselineColor

> this.baselineColor = null

CSS color spec for the baseline.

### forceTickAt0

> this.forceTickAt0 = false

This will ensure that there is always a tick mark at 0. If data range is strictly positive or negative, this will force 0 to be inside the axis bounds unless the appropriate axis pad (pad, padMin or padMax) is set to 0, then this will force an axis min or max value at 0. This has know effect when any of the following options are set: autoscale, min, max, numberTicks or tickInterval.

### forceTickAt100

> this.forceTickAt100 = false

This will ensure that there is always a tick mark at 100. If data range is strictly above or below 100, this will force 100 to be inside the axis bounds unless the appropriate axis pad (pad, padMin or padMax) is set to 0, then this will force an axis min or max value at 100. This has know effect when any of the following options are set: autoscale, min, max, numberTicks or tickInterval.

### tickInset

> this.tickInset = 0

Controls the amount to inset the first and last ticks from the edges of the grid, in multiples of the tick interval. 0 is no inset, 0.5 is one half a tick interval, 1 is a full tick interval, etc.

### minorTicks

> this.minorTicks = 0

Number of ticks to add between “major” ticks. Major ticks are ticks supplied by user or auto computed. Minor ticks cannot be created by user.

### alignTicks

> this.alignTicks = false

true to align tick marks across opposed axes such as from the y2axis to yaxis.

> this.breakPoints = null

EXPERIMENTAL!!

> this.breakTickLabel = "&asymp

Label to use at the axis break if breakPoints are specified.

> this.drawBaseline = true

True to draw the axis baseline.

> this.baselineWidth = null

width of the baseline in pixels.

> this.baselineColor = null

CSS color spec for the baseline.

> this.forceTickAt0 = false

This will ensure that there is always a tick mark at 0.

> this.forceTickAt100 = false

This will ensure that there is always a tick mark at 100.

> this.tickInset = 0

Controls the amount to inset the first and last ticks from the edges of the grid, in multiples of the tick interval.

> this.minorTicks = 0

Number of ticks to add between “major” ticks.

> this.alignTicks = false

true to align tick marks across opposed axes such as from the y2axis to yaxis.
Close